@@ -1,7 +1,9 @@
 package Complete;
 
-our $DATE = '2019-06-26'; # DATE
-our $VERSION = '0.201'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-01-28'; # DATE
+our $DIST = 'Complete'; # DIST
+our $VERSION = '0.202'; # VERSION
 
 1;
 # ABSTRACT: Convention for Complete::* modules family
@@ -18,15 +20,15 @@ Complete - Convention for Complete::* modules family
 
 =head1 VERSION
 
-This document describes version 0.201 of Complete (from Perl distribution Complete), released on 2019-06-26.
+This document describes version 0.202 of Complete (from Perl distribution Complete), released on 2020-01-28.
 
 =head1 DESCRIPTION
 
 The namespace C<Complete::> is used for the family of modules that deal with
 completion (including, but not limited to, shell tab completion, tab completion
 feature in other CLI-based application, web autocomplete, completion in GUI,
-etc). This (family of) modules try to have a clear separation between general
-completion routine and shell-/environment specific ones, for more reusability.
+etc). These modules try to have a clear separation between general completion
+routine and shell-/environment specific ones, for more reusability.
 
 This POD page establishes convention and gives an overview of the modules in
 C<Complete::*>.
@@ -100,32 +102,32 @@ See L</"Completion answer structure">.
 
 =head2 Completion answer structure
 
-C<complete_*()> functions return completion answer structure. Completion answer
+C<complete_*()> functions return completion answer structure. This structure
 contains the completion entries as well as extra metadata to give hints to
-formatters/tools. It is a hashref which can contain the following keys:
+formatters/tools.
+
+=head3 Hash form
+
+It is a L<DefHash> which can contain the following keys:
 
 =over
 
-=item * message => string
+=item * words => array|hash
 
-Experimental. Instead of returning completion entries, a completion answer can
-also opt to request showing a message (i.e. error message, or informational
-message) to the user.
-
-=item * words => array
-
-Its value is an array of completion entries. A completion entry can be a string
-or a hashref. Example:
+Required (unless C<message> is present). Its value is an array of completion
+entries. A completion entry can be a string or a hashref (a L<DefHash>).
+Example:
 
  ['apple', 'apricot'] # array of strings
 
  [{word=>'apple', summary=>'A delicious fruit with thousands of varieties'},
   {word=>'apricot', summary=>'Another delicious fruit'},] # array of hashes
 
-As you can see from the above, each entry specify the B<word> and can also
-contain additional information: B<summary> (str, short one-line description, can
-be displayed e.g. in shells that support them, like fish and zsh), B<is_partial>
-(bool, specify whether this is a partial completion).
+As you can see from the above, each entry specifies the B<word> and can also
+contain additional information: B<summary> (str, short one-line description
+about the entry, can be displayed alongside the entry), B<is_partial> (bool,
+specify whether this is a partial completion which means the word is not the
+full entry).
 
  # example of digit-by-digit completion
  [
@@ -137,35 +139,62 @@ be displayed e.g. in shells that support them, like fish and zsh), B<is_partial>
 
 =item * is_partial => bool
 
-If set to true, specifies that the entries in B<words> are partial completion
-entries. This is equivalent to setting C<< is_partial => 1 >> to all the
-entries.
-
-=item * type => str
-
-See L<Complete::Bash>.
+Optional. If set to true, specifies that the entries in B<words> are partial
+completion entries. This is equivalent to setting C<< is_partial => 1 >> to all
+the entries.
 
 =item * path_sep => str
 
-See L<Complete::Bash>.
+Optional. If set, express that the completion should be done in "path mode",
+useful for completing/drilling-down path.
 
-=item * esc_mode => str
+In shells like bash, for example, when completing filename (e.g. C<foo>) and
+there is only a single possible completion (e.g. C<foo> or C<foo.txt>), the
+shell will display the completion in the buffer and automatically add a space so
+the user can move to the next argument. This is also true when completing other
+values like variables or program names.
 
-See L<Complete::Bash>.
+However, when completing directory (e.g. C</et> or C<Downloads>) and there is
+solely a single completion possible and it is a directory (e.g. C</etc> or
+C<Downloads>), instead of adding a space, the shell will automatically add the
+path separator character (C</etc/> or C<Downloads/>). The user can press Tab
+again to complete for files/directories inside that directory, and so on. This
+is obviously more convenient compared to when shell adds a space instead.
+
+Path mode is not restricted to completing filesystem paths. Anything path-like
+can use it. For example when you are completing Java or Perl module name (e.g.
+C<com.company.product.whatever> or C<File::Spec::Unix>) you can use this mode
+(with C<path_sep> appropriately set to, e.g. C<.> or C<::>).
 
 =item * static => bool
 
-Specify that completion is "static", meaning that it does not depend on external
-state (like filesystem) or a custom code which can return different answer
-everytime completion is requested.
+Optional. Specifies that completion is "static", meaning that it does not depend
+on external state (like filesystem) or a custom code which can return different
+answer everytime completion is requested.
 
 This can be useful for code that wants to generate completion code, like bash
 completion or fish completion. Knowing that completion for an option value is
 static means that completion for that option can be answered from an array
 instead of having to call code/program (faster).
 
+=item * message => string
+
+Optional. Instead of returning completion entries (C<words>), a completion
+answer can also opt to request showing a message (i.e. error message, or
+informational message) to the user.
+
 =back
 
+Implementations that want to observe more information can do so in the
+C<x.NAME.WHATEVER> attribute, as per recommended by DefHash. For example:
+
+ {
+  words => ["foo", "bar"],
+  'x.bash.escape_dollar' => 1,
+ }
+
+=head3 Array form
+
 As a shortcut, completion answer can also be an arrayref (just the C<words>)
 without any metadata.
 
@@ -206,7 +235,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
